bayespy.nodes.CategoricalMarkovChain.get_riemannian_gradient
============================================================

.. currentmodule:: bayespy.nodes

.. automethod:: CategoricalMarkovChain.get_riemannian_gradient